A collection of Python dictionaries supporting attribute-style access. Includes
*defaultdict*,  *OrderedDict*, restricted, *ChainMap*, and frozen
implementations plus miscellaneous useful utilities for writing Python software.